Documentation
¶
Index ¶
- Constants
- func PipelineCancelPipeline(ctx context.Context, c util.LexClient, input *PipelineCancelPipeline_Input) error
- func RepoAddSecret(ctx context.Context, c util.LexClient, input *RepoAddSecret_Input) error
- func RepoArchive(ctx context.Context, c util.LexClient, format string, prefix string, ...) ([]byte, error)
- func RepoBranches(ctx context.Context, c util.LexClient, cursor string, limit int64, repo string) ([]byte, error)
- func RepoCompare(ctx context.Context, c util.LexClient, repo string, rev1 string, rev2 string) ([]byte, error)
- func RepoCreate(ctx context.Context, c util.LexClient, input *RepoCreate_Input) error
- func RepoDelete(ctx context.Context, c util.LexClient, input *RepoDelete_Input) error
- func RepoDeleteBranch(ctx context.Context, c util.LexClient, input *RepoDeleteBranch_Input) error
- func RepoDiff(ctx context.Context, c util.LexClient, ref string, repo string) ([]byte, error)
- func RepoForkSync(ctx context.Context, c util.LexClient, input *RepoForkSync_Input) error
- func RepoLog(ctx context.Context, c util.LexClient, cursor string, limit int64, path string, ...) ([]byte, error)
- func RepoMerge(ctx context.Context, c util.LexClient, input *RepoMerge_Input) error
- func RepoRemoveSecret(ctx context.Context, c util.LexClient, input *RepoRemoveSecret_Input) error
- func RepoSetDefaultBranch(ctx context.Context, c util.LexClient, input *RepoSetDefaultBranch_Input) error
- func RepoTag(ctx context.Context, c util.LexClient, repo string, tag string) ([]byte, error)
- func RepoTags(ctx context.Context, c util.LexClient, cursor string, limit int64, repo string) ([]byte, error)
- type ActorProfile
- type FeedReaction
- type FeedStar
- type GitRefUpdate
- type GitRefUpdate_CommitCountBreakdown
- type GitRefUpdate_IndividualEmailCommitCount
- type GitRefUpdate_IndividualLanguageSize
- type GitRefUpdate_LangBreakdown
- type GitRefUpdate_Meta
- type GraphFollow
- type Knot
- type KnotListKeys_Output
- type KnotListKeys_PublicKey
- type KnotMember
- type KnotVersion_Output
- type LabelDefinition
- type LabelDefinition_ValueType
- type LabelOp
- type LabelOp_Operand
- type Owner_Output
- type Pipeline
- type PipelineCancelPipeline_Input
- type PipelineStatus
- type Pipeline_CloneOpts
- type Pipeline_ManualTriggerData
- type Pipeline_Pair
- type Pipeline_PullRequestTriggerData
- type Pipeline_PushTriggerData
- type Pipeline_TriggerMetadata
- type Pipeline_TriggerRepo
- type Pipeline_Workflow
- type PublicKey
- type Repo
- type RepoAddSecret_Input
- type RepoArtifact
- type RepoBlob_LastCommit
- type RepoBlob_Output
- type RepoBlob_Signature
- type RepoBlob_Submodule
- type RepoBranch_Output
- type RepoBranch_Signature
- type RepoCollaborator
- type RepoCreate_Input
- type RepoDeleteBranch_Input
- type RepoDelete_Input
- type RepoForkStatus_Input
- type RepoForkStatus_Output
- type RepoForkSync_Input
- type RepoGetDefaultBranch_Output
- type RepoGetDefaultBranch_Signature
- type RepoHiddenRef_Input
- type RepoHiddenRef_Output
- type RepoIssue
- type RepoIssueComment
- type RepoIssueState
- type RepoLanguages_Language
- type RepoLanguages_Output
- type RepoListSecrets_Output
- type RepoListSecrets_Secret
- type RepoMergeCheck_ConflictInfo
- type RepoMergeCheck_Input
- type RepoMergeCheck_Output
- type RepoMerge_Input
- type RepoPull
- type RepoPullComment
- type RepoPullStatus
- type RepoPull_Source
- type RepoPull_Target
- type RepoRemoveSecret_Input
- type RepoSetDefaultBranch_Input
- type RepoTree_LastCommit
- type RepoTree_Output
- type RepoTree_Readme
- type RepoTree_Signature
- type RepoTree_TreeEntry
- type Spindle
- type SpindleMember
- type String
Constants ¶
const (
ActorProfileNSID = "sh.tangled.actor.profile"
)
const (
FeedReactionNSID = "sh.tangled.feed.reaction"
)
const (
FeedStarNSID = "sh.tangled.feed.star"
)
const (
GitRefUpdateNSID = "sh.tangled.git.refUpdate"
)
const (
GraphFollowNSID = "sh.tangled.graph.follow"
)
const (
KnotListKeysNSID = "sh.tangled.knot.listKeys"
)
const (
KnotMemberNSID = "sh.tangled.knot.member"
)
const (
KnotNSID = "sh.tangled.knot"
)
const (
KnotVersionNSID = "sh.tangled.knot.version"
)
const (
LabelDefinitionNSID = "sh.tangled.label.definition"
)
const (
LabelOpNSID = "sh.tangled.label.op"
)
const (
OwnerNSID = "sh.tangled.owner"
)
const (
PipelineCancelPipelineNSID = "sh.tangled.pipeline.cancelPipeline"
)
const (
PipelineNSID = "sh.tangled.pipeline"
)
const (
PipelineStatusNSID = "sh.tangled.pipeline.status"
)
const (
PublicKeyNSID = "sh.tangled.publicKey"
)
const (
RepoAddSecretNSID = "sh.tangled.repo.addSecret"
)
const (
RepoArchiveNSID = "sh.tangled.repo.archive"
)
const (
RepoArtifactNSID = "sh.tangled.repo.artifact"
)
const (
RepoBlobNSID = "sh.tangled.repo.blob"
)
const (
RepoBranchNSID = "sh.tangled.repo.branch"
)
const (
RepoBranchesNSID = "sh.tangled.repo.branches"
)
const (
RepoCollaboratorNSID = "sh.tangled.repo.collaborator"
)
const (
RepoCompareNSID = "sh.tangled.repo.compare"
)
const (
RepoCreateNSID = "sh.tangled.repo.create"
)
const (
RepoDeleteBranchNSID = "sh.tangled.repo.deleteBranch"
)
const (
RepoDeleteNSID = "sh.tangled.repo.delete"
)
const (
RepoDiffNSID = "sh.tangled.repo.diff"
)
const (
RepoForkStatusNSID = "sh.tangled.repo.forkStatus"
)
const (
RepoForkSyncNSID = "sh.tangled.repo.forkSync"
)
const (
RepoGetDefaultBranchNSID = "sh.tangled.repo.getDefaultBranch"
)
const (
RepoHiddenRefNSID = "sh.tangled.repo.hiddenRef"
)
const (
RepoIssueCommentNSID = "sh.tangled.repo.issue.comment"
)
const (
RepoIssueNSID = "sh.tangled.repo.issue"
)
const RepoIssueStateClosed = "sh.tangled.repo.issue.state.closed"
const (
RepoIssueStateClosedNSID = "sh.tangled.repo.issue.state.closed"
)
const (
RepoIssueStateNSID = "sh.tangled.repo.issue.state"
)
const RepoIssueStateOpen = "sh.tangled.repo.issue.state.open"
const (
RepoIssueStateOpenNSID = "sh.tangled.repo.issue.state.open"
)
const (
RepoLanguagesNSID = "sh.tangled.repo.languages"
)
const (
RepoListSecretsNSID = "sh.tangled.repo.listSecrets"
)
const (
RepoLogNSID = "sh.tangled.repo.log"
)
const (
RepoMergeCheckNSID = "sh.tangled.repo.mergeCheck"
)
const (
RepoMergeNSID = "sh.tangled.repo.merge"
)
const (
RepoNSID = "sh.tangled.repo"
)
const (
RepoPullCommentNSID = "sh.tangled.repo.pull.comment"
)
const (
RepoPullNSID = "sh.tangled.repo.pull"
)
const RepoPullStatusClosed = "sh.tangled.repo.pull.status.closed"
const (
RepoPullStatusClosedNSID = "sh.tangled.repo.pull.status.closed"
)
const RepoPullStatusMerged = "sh.tangled.repo.pull.status.merged"
const (
RepoPullStatusMergedNSID = "sh.tangled.repo.pull.status.merged"
)
const (
RepoPullStatusNSID = "sh.tangled.repo.pull.status"
)
const RepoPullStatusOpen = "sh.tangled.repo.pull.status.open"
const (
RepoPullStatusOpenNSID = "sh.tangled.repo.pull.status.open"
)
const (
RepoRemoveSecretNSID = "sh.tangled.repo.removeSecret"
)
const (
RepoSetDefaultBranchNSID = "sh.tangled.repo.setDefaultBranch"
)
const (
RepoTagNSID = "sh.tangled.repo.tag"
)
const (
RepoTagsNSID = "sh.tangled.repo.tags"
)
const (
RepoTreeNSID = "sh.tangled.repo.tree"
)
const (
SpindleMemberNSID = "sh.tangled.spindle.member"
)
const (
SpindleNSID = "sh.tangled.spindle"
)
const (
StringNSID = "sh.tangled.string"
)
Variables ¶
This section is empty.
Functions ¶
func PipelineCancelPipeline ¶
func PipelineCancelPipeline(ctx context.Context, c util.LexClient, input *PipelineCancelPipeline_Input) error
PipelineCancelPipeline calls the XRPC method "sh.tangled.pipeline.cancelPipeline".
func RepoAddSecret ¶
RepoAddSecret calls the XRPC method "sh.tangled.repo.addSecret".
func RepoArchive ¶
func RepoArchive(ctx context.Context, c util.LexClient, format string, prefix string, ref string, repo string) ([]byte, error)
RepoArchive calls the XRPC method "sh.tangled.repo.archive".
format: Archive format prefix: Prefix for files in the archive ref: Git reference (branch, tag, or commit SHA) repo: Repository identifier in format 'did:plc:.../repoName'
func RepoBranches ¶
func RepoBranches(ctx context.Context, c util.LexClient, cursor string, limit int64, repo string) ([]byte, error)
RepoBranches calls the XRPC method "sh.tangled.repo.branches".
cursor: Pagination cursor limit: Maximum number of branches to return repo: Repository identifier in format 'did:plc:.../repoName'
func RepoCompare ¶
func RepoCompare(ctx context.Context, c util.LexClient, repo string, rev1 string, rev2 string) ([]byte, error)
RepoCompare calls the XRPC method "sh.tangled.repo.compare".
repo: Repository identifier in format 'did:plc:.../repoName' rev1: First revision (commit, branch, or tag) rev2: Second revision (commit, branch, or tag)
func RepoCreate ¶
RepoCreate calls the XRPC method "sh.tangled.repo.create".
func RepoDelete ¶
RepoDelete calls the XRPC method "sh.tangled.repo.delete".
func RepoDeleteBranch ¶
RepoDeleteBranch calls the XRPC method "sh.tangled.repo.deleteBranch".
func RepoDiff ¶
RepoDiff calls the XRPC method "sh.tangled.repo.diff".
ref: Git reference (branch, tag, or commit SHA) repo: Repository identifier in format 'did:plc:.../repoName'
func RepoForkSync ¶
RepoForkSync calls the XRPC method "sh.tangled.repo.forkSync".
func RepoLog ¶
func RepoLog(ctx context.Context, c util.LexClient, cursor string, limit int64, path string, ref string, repo string) ([]byte, error)
RepoLog calls the XRPC method "sh.tangled.repo.log".
cursor: Pagination cursor (commit SHA) limit: Maximum number of commits to return path: Path to filter commits by ref: Git reference (branch, tag, or commit SHA) repo: Repository identifier in format 'did:plc:.../repoName'
func RepoMerge ¶
RepoMerge calls the XRPC method "sh.tangled.repo.merge".
func RepoRemoveSecret ¶
RepoRemoveSecret calls the XRPC method "sh.tangled.repo.removeSecret".
func RepoSetDefaultBranch ¶
func RepoSetDefaultBranch(ctx context.Context, c util.LexClient, input *RepoSetDefaultBranch_Input) error
RepoSetDefaultBranch calls the XRPC method "sh.tangled.repo.setDefaultBranch".
func RepoTag ¶
RepoTag calls the XRPC method "sh.tangled.repo.tag".
repo: Repository identifier in format 'did:plc:.../repoName' tag: Name of tag, such as v1.3.0
func RepoTags ¶
func RepoTags(ctx context.Context, c util.LexClient, cursor string, limit int64, repo string) ([]byte, error)
RepoTags calls the XRPC method "sh.tangled.repo.tags".
cursor: Pagination cursor limit: Maximum number of tags to return repo: Repository identifier in format 'did:plc:.../repoName'
Types ¶
type ActorProfile ¶
type ActorProfile struct {
LexiconTypeID string `json:"$type,const=sh.tangled.actor.profile" cborgen:"$type,const=sh.tangled.actor.profile"`
// avatar: Small image to be displayed next to posts from account. AKA, 'profile picture'
Avatar *util.LexBlob `json:"avatar,omitempty" cborgen:"avatar,omitempty"`
// bluesky: Include link to this account on Bluesky.
Bluesky bool `json:"bluesky" cborgen:"bluesky"`
// description: Free-form profile description text.
Description *string `json:"description,omitempty" cborgen:"description,omitempty"`
Links []string `json:"links,omitempty" cborgen:"links,omitempty"`
// location: Free-form location text.
Location *string `json:"location,omitempty" cborgen:"location,omitempty"`
// pinnedRepositories: Any ATURI, it is up to appviews to validate these fields.
PinnedRepositories []string `json:"pinnedRepositories,omitempty" cborgen:"pinnedRepositories,omitempty"`
// pronouns: Preferred gender pronouns.
Pronouns *string `json:"pronouns,omitempty" cborgen:"pronouns,omitempty"`
Stats []string `json:"stats,omitempty" cborgen:"stats,omitempty"`
}
RECORDTYPE: ActorProfile
func (*ActorProfile) MarshalCBOR ¶
func (t *ActorProfile) MarshalCBOR(w io.Writer) error
func (*ActorProfile) UnmarshalCBOR ¶
func (t *ActorProfile) UnmarshalCBOR(r io.Reader) (err error)
type FeedReaction ¶
type FeedReaction struct {
LexiconTypeID string `json:"$type,const=sh.tangled.feed.reaction" cborgen:"$type,const=sh.tangled.feed.reaction"`
CreatedAt string `json:"createdAt" cborgen:"createdAt"`
Reaction string `json:"reaction" cborgen:"reaction"`
Subject string `json:"subject" cborgen:"subject"`
}
RECORDTYPE: FeedReaction
func (*FeedReaction) MarshalCBOR ¶
func (t *FeedReaction) MarshalCBOR(w io.Writer) error
func (*FeedReaction) UnmarshalCBOR ¶
func (t *FeedReaction) UnmarshalCBOR(r io.Reader) (err error)
type FeedStar ¶
type FeedStar struct {
LexiconTypeID string `json:"$type,const=sh.tangled.feed.star" cborgen:"$type,const=sh.tangled.feed.star"`
CreatedAt string `json:"createdAt" cborgen:"createdAt"`
Subject string `json:"subject" cborgen:"subject"`
}
RECORDTYPE: FeedStar
type GitRefUpdate ¶
type GitRefUpdate struct {
LexiconTypeID string `json:"$type,const=sh.tangled.git.refUpdate" cborgen:"$type,const=sh.tangled.git.refUpdate"`
// committerDid: did of the user that pushed this ref
CommitterDid string `json:"committerDid" cborgen:"committerDid"`
Meta *GitRefUpdate_Meta `json:"meta" cborgen:"meta"`
// newSha: new SHA of this ref
NewSha string `json:"newSha" cborgen:"newSha"`
// oldSha: old SHA of this ref
OldSha string `json:"oldSha" cborgen:"oldSha"`
// ref: Ref being updated
Ref string `json:"ref" cborgen:"ref"`
// repoDid: did of the owner of the repo
RepoDid string `json:"repoDid" cborgen:"repoDid"`
// repoName: name of the repo
RepoName string `json:"repoName" cborgen:"repoName"`
}
RECORDTYPE: GitRefUpdate
func (*GitRefUpdate) MarshalCBOR ¶
func (t *GitRefUpdate) MarshalCBOR(w io.Writer) error
func (*GitRefUpdate) UnmarshalCBOR ¶
func (t *GitRefUpdate) UnmarshalCBOR(r io.Reader) (err error)
type GitRefUpdate_CommitCountBreakdown ¶
type GitRefUpdate_CommitCountBreakdown struct {
ByEmail []*GitRefUpdate_IndividualEmailCommitCount `json:"byEmail,omitempty" cborgen:"byEmail,omitempty"`
}
GitRefUpdate_CommitCountBreakdown is a "commitCountBreakdown" in the sh.tangled.git.refUpdate schema.
func (*GitRefUpdate_CommitCountBreakdown) MarshalCBOR ¶
func (t *GitRefUpdate_CommitCountBreakdown) MarshalCBOR(w io.Writer) error
func (*GitRefUpdate_CommitCountBreakdown) UnmarshalCBOR ¶
func (t *GitRefUpdate_CommitCountBreakdown) UnmarshalCBOR(r io.Reader) (err error)
type GitRefUpdate_IndividualEmailCommitCount ¶
type GitRefUpdate_IndividualEmailCommitCount struct {
Count int64 `json:"count" cborgen:"count"`
Email string `json:"email" cborgen:"email"`
}
GitRefUpdate_IndividualEmailCommitCount is a "individualEmailCommitCount" in the sh.tangled.git.refUpdate schema.
func (*GitRefUpdate_IndividualEmailCommitCount) MarshalCBOR ¶
func (t *GitRefUpdate_IndividualEmailCommitCount) MarshalCBOR(w io.Writer) error
func (*GitRefUpdate_IndividualEmailCommitCount) UnmarshalCBOR ¶
func (t *GitRefUpdate_IndividualEmailCommitCount) UnmarshalCBOR(r io.Reader) (err error)
type GitRefUpdate_IndividualLanguageSize ¶
type GitRefUpdate_IndividualLanguageSize struct {
Lang string `json:"lang" cborgen:"lang"`
Size int64 `json:"size" cborgen:"size"`
}
GitRefUpdate_IndividualLanguageSize is a "individualLanguageSize" in the sh.tangled.git.refUpdate schema.
func (*GitRefUpdate_IndividualLanguageSize) MarshalCBOR ¶
func (t *GitRefUpdate_IndividualLanguageSize) MarshalCBOR(w io.Writer) error
func (*GitRefUpdate_IndividualLanguageSize) UnmarshalCBOR ¶
func (t *GitRefUpdate_IndividualLanguageSize) UnmarshalCBOR(r io.Reader) (err error)
type GitRefUpdate_LangBreakdown ¶
type GitRefUpdate_LangBreakdown struct {
Inputs []*GitRefUpdate_IndividualLanguageSize `json:"inputs,omitempty" cborgen:"inputs,omitempty"`
}
GitRefUpdate_LangBreakdown is a "langBreakdown" in the sh.tangled.git.refUpdate schema.
func (*GitRefUpdate_LangBreakdown) MarshalCBOR ¶
func (t *GitRefUpdate_LangBreakdown) MarshalCBOR(w io.Writer) error
func (*GitRefUpdate_LangBreakdown) UnmarshalCBOR ¶
func (t *GitRefUpdate_LangBreakdown) UnmarshalCBOR(r io.Reader) (err error)
type GitRefUpdate_Meta ¶
type GitRefUpdate_Meta struct {
CommitCount *GitRefUpdate_CommitCountBreakdown `json:"commitCount" cborgen:"commitCount"`
IsDefaultRef bool `json:"isDefaultRef" cborgen:"isDefaultRef"`
LangBreakdown *GitRefUpdate_LangBreakdown `json:"langBreakdown,omitempty" cborgen:"langBreakdown,omitempty"`
}
GitRefUpdate_Meta is a "meta" in the sh.tangled.git.refUpdate schema.
func (*GitRefUpdate_Meta) MarshalCBOR ¶
func (t *GitRefUpdate_Meta) MarshalCBOR(w io.Writer) error
func (*GitRefUpdate_Meta) UnmarshalCBOR ¶
func (t *GitRefUpdate_Meta) UnmarshalCBOR(r io.Reader) (err error)
type GraphFollow ¶
type GraphFollow struct {
LexiconTypeID string `json:"$type,const=sh.tangled.graph.follow" cborgen:"$type,const=sh.tangled.graph.follow"`
CreatedAt string `json:"createdAt" cborgen:"createdAt"`
Subject string `json:"subject" cborgen:"subject"`
}
RECORDTYPE: GraphFollow
func (*GraphFollow) MarshalCBOR ¶
func (t *GraphFollow) MarshalCBOR(w io.Writer) error
func (*GraphFollow) UnmarshalCBOR ¶
func (t *GraphFollow) UnmarshalCBOR(r io.Reader) (err error)
type Knot ¶
type Knot struct {
LexiconTypeID string `json:"$type,const=sh.tangled.knot" cborgen:"$type,const=sh.tangled.knot"`
CreatedAt string `json:"createdAt" cborgen:"createdAt"`
}
RECORDTYPE: Knot
type KnotListKeys_Output ¶
type KnotListKeys_Output struct {
// cursor: Pagination cursor for next page
Cursor *string `json:"cursor,omitempty" cborgen:"cursor,omitempty"`
Keys []*KnotListKeys_PublicKey `json:"keys" cborgen:"keys"`
}
KnotListKeys_Output is the output of a sh.tangled.knot.listKeys call.
type KnotListKeys_PublicKey ¶
type KnotListKeys_PublicKey struct {
// createdAt: Key upload timestamp
CreatedAt string `json:"createdAt" cborgen:"createdAt"`
// did: DID associated with the public key
Did string `json:"did" cborgen:"did"`
// key: Public key contents
Key string `json:"key" cborgen:"key"`
}
KnotListKeys_PublicKey is a "publicKey" in the sh.tangled.knot.listKeys schema.
type KnotMember ¶
type KnotMember struct {
LexiconTypeID string `json:"$type,const=sh.tangled.knot.member" cborgen:"$type,const=sh.tangled.knot.member"`
CreatedAt string `json:"createdAt" cborgen:"createdAt"`
// domain: domain that this member now belongs to
Domain string `json:"domain" cborgen:"domain"`
Subject string `json:"subject" cborgen:"subject"`
}
RECORDTYPE: KnotMember
func (*KnotMember) MarshalCBOR ¶
func (t *KnotMember) MarshalCBOR(w io.Writer) error
func (*KnotMember) UnmarshalCBOR ¶
func (t *KnotMember) UnmarshalCBOR(r io.Reader) (err error)
type KnotVersion_Output ¶
type KnotVersion_Output struct {
Version string `json:"version" cborgen:"version"`
}
KnotVersion_Output is the output of a sh.tangled.knot.version call.
type LabelDefinition ¶
type LabelDefinition struct {
LexiconTypeID string `json:"$type,const=sh.tangled.label.definition" cborgen:"$type,const=sh.tangled.label.definition"`
// color: The hex value for the background color for the label. Appviews may choose to respect this.
Color *string `json:"color,omitempty" cborgen:"color,omitempty"`
CreatedAt string `json:"createdAt" cborgen:"createdAt"`
// multiple: Whether this label can be repeated for a given entity, eg.: [reviewer:foo, reviewer:bar]
Multiple *bool `json:"multiple,omitempty" cborgen:"multiple,omitempty"`
// name: The display name of this label.
Name string `json:"name" cborgen:"name"`
// scope: The areas of the repo this label may apply to, eg.: sh.tangled.repo.issue. Appviews may choose to respect this.
Scope []string `json:"scope" cborgen:"scope"`
// valueType: The type definition of this label. Appviews may allow sorting for certain types.
ValueType *LabelDefinition_ValueType `json:"valueType" cborgen:"valueType"`
}
RECORDTYPE: LabelDefinition
func (*LabelDefinition) MarshalCBOR ¶
func (t *LabelDefinition) MarshalCBOR(w io.Writer) error
func (*LabelDefinition) UnmarshalCBOR ¶
func (t *LabelDefinition) UnmarshalCBOR(r io.Reader) (err error)
type LabelDefinition_ValueType ¶
type LabelDefinition_ValueType struct {
// enum: Closed set of values that this label can take.
Enum []string `json:"enum,omitempty" cborgen:"enum,omitempty"`
// format: An optional constraint that can be applied on string concrete types.
Format string `json:"format" cborgen:"format"`
// type: The concrete type of this label's value.
Type string `json:"type" cborgen:"type"`
}
LabelDefinition_ValueType is a "valueType" in the sh.tangled.label.definition schema.
func (*LabelDefinition_ValueType) MarshalCBOR ¶
func (t *LabelDefinition_ValueType) MarshalCBOR(w io.Writer) error
func (*LabelDefinition_ValueType) UnmarshalCBOR ¶
func (t *LabelDefinition_ValueType) UnmarshalCBOR(r io.Reader) (err error)
type LabelOp ¶
type LabelOp struct {
LexiconTypeID string `json:"$type,const=sh.tangled.label.op" cborgen:"$type,const=sh.tangled.label.op"`
Add []*LabelOp_Operand `json:"add" cborgen:"add"`
Delete []*LabelOp_Operand `json:"delete" cborgen:"delete"`
PerformedAt string `json:"performedAt" cborgen:"performedAt"`
// subject: The subject (task, pull or discussion) of this label. Appviews may apply a `scope` check and refuse this op.
Subject string `json:"subject" cborgen:"subject"`
}
RECORDTYPE: LabelOp
type LabelOp_Operand ¶
type LabelOp_Operand struct {
// key: ATURI to the label definition
Key string `json:"key" cborgen:"key"`
// value: Stringified value of the label. This is first unstringed by appviews and then interpreted as a concrete value.
Value string `json:"value" cborgen:"value"`
}
LabelOp_Operand is a "operand" in the sh.tangled.label.op schema.
func (*LabelOp_Operand) MarshalCBOR ¶
func (t *LabelOp_Operand) MarshalCBOR(w io.Writer) error
func (*LabelOp_Operand) UnmarshalCBOR ¶
func (t *LabelOp_Operand) UnmarshalCBOR(r io.Reader) (err error)
type Owner_Output ¶
type Owner_Output struct {
Owner string `json:"owner" cborgen:"owner"`
}
Owner_Output is the output of a sh.tangled.owner call.
type Pipeline ¶
type Pipeline struct {
LexiconTypeID string `json:"$type,const=sh.tangled.pipeline" cborgen:"$type,const=sh.tangled.pipeline"`
TriggerMetadata *Pipeline_TriggerMetadata `json:"triggerMetadata" cborgen:"triggerMetadata"`
Workflows []*Pipeline_Workflow `json:"workflows" cborgen:"workflows"`
}
RECORDTYPE: Pipeline
type PipelineCancelPipeline_Input ¶
type PipelineCancelPipeline_Input struct {
// pipeline: pipeline at-uri
Pipeline string `json:"pipeline" cborgen:"pipeline"`
// repo: repo at-uri, spindle can't resolve repo from pipeline at-uri yet
Repo string `json:"repo" cborgen:"repo"`
// workflow: workflow name
Workflow string `json:"workflow" cborgen:"workflow"`
}
PipelineCancelPipeline_Input is the input argument to a sh.tangled.pipeline.cancelPipeline call.
type PipelineStatus ¶
type PipelineStatus struct {
LexiconTypeID string `json:"$type,const=sh.tangled.pipeline.status" cborgen:"$type,const=sh.tangled.pipeline.status"`
// createdAt: time of creation of this status update
CreatedAt string `json:"createdAt" cborgen:"createdAt"`
// error: error message if failed
Error *string `json:"error,omitempty" cborgen:"error,omitempty"`
// exitCode: exit code if failed
ExitCode *int64 `json:"exitCode,omitempty" cborgen:"exitCode,omitempty"`
// pipeline: ATURI of the pipeline
Pipeline string `json:"pipeline" cborgen:"pipeline"`
// status: status of the workflow
Status string `json:"status" cborgen:"status"`
// workflow: name of the workflow within this pipeline
Workflow string `json:"workflow" cborgen:"workflow"`
}
RECORDTYPE: PipelineStatus
func (*PipelineStatus) MarshalCBOR ¶
func (t *PipelineStatus) MarshalCBOR(w io.Writer) error
func (*PipelineStatus) UnmarshalCBOR ¶
func (t *PipelineStatus) UnmarshalCBOR(r io.Reader) (err error)
type Pipeline_CloneOpts ¶
type Pipeline_CloneOpts struct {
Depth int64 `json:"depth" cborgen:"depth"`
Skip bool `json:"skip" cborgen:"skip"`
Submodules bool `json:"submodules" cborgen:"submodules"`
}
Pipeline_CloneOpts is a "cloneOpts" in the sh.tangled.pipeline schema.
func (*Pipeline_CloneOpts) MarshalCBOR ¶
func (t *Pipeline_CloneOpts) MarshalCBOR(w io.Writer) error
func (*Pipeline_CloneOpts) UnmarshalCBOR ¶
func (t *Pipeline_CloneOpts) UnmarshalCBOR(r io.Reader) (err error)
type Pipeline_ManualTriggerData ¶
type Pipeline_ManualTriggerData struct {
Inputs []*Pipeline_Pair `json:"inputs,omitempty" cborgen:"inputs,omitempty"`
}
Pipeline_ManualTriggerData is a "manualTriggerData" in the sh.tangled.pipeline schema.
func (*Pipeline_ManualTriggerData) MarshalCBOR ¶
func (t *Pipeline_ManualTriggerData) MarshalCBOR(w io.Writer) error
func (*Pipeline_ManualTriggerData) UnmarshalCBOR ¶
func (t *Pipeline_ManualTriggerData) UnmarshalCBOR(r io.Reader) (err error)
type Pipeline_Pair ¶
type Pipeline_Pair struct {
Key string `json:"key" cborgen:"key"`
Value string `json:"value" cborgen:"value"`
}
Pipeline_Pair is a "pair" in the sh.tangled.pipeline schema.
func (*Pipeline_Pair) MarshalCBOR ¶
func (t *Pipeline_Pair) MarshalCBOR(w io.Writer) error
func (*Pipeline_Pair) UnmarshalCBOR ¶
func (t *Pipeline_Pair) UnmarshalCBOR(r io.Reader) (err error)
type Pipeline_PullRequestTriggerData ¶
type Pipeline_PullRequestTriggerData struct {
Action string `json:"action" cborgen:"action"`
SourceBranch string `json:"sourceBranch" cborgen:"sourceBranch"`
SourceSha string `json:"sourceSha" cborgen:"sourceSha"`
TargetBranch string `json:"targetBranch" cborgen:"targetBranch"`
}
Pipeline_PullRequestTriggerData is a "pullRequestTriggerData" in the sh.tangled.pipeline schema.
func (*Pipeline_PullRequestTriggerData) MarshalCBOR ¶
func (t *Pipeline_PullRequestTriggerData) MarshalCBOR(w io.Writer) error
func (*Pipeline_PullRequestTriggerData) UnmarshalCBOR ¶
func (t *Pipeline_PullRequestTriggerData) UnmarshalCBOR(r io.Reader) (err error)
type Pipeline_PushTriggerData ¶
type Pipeline_PushTriggerData struct {
NewSha string `json:"newSha" cborgen:"newSha"`
OldSha string `json:"oldSha" cborgen:"oldSha"`
Ref string `json:"ref" cborgen:"ref"`
}
Pipeline_PushTriggerData is a "pushTriggerData" in the sh.tangled.pipeline schema.
func (*Pipeline_PushTriggerData) MarshalCBOR ¶
func (t *Pipeline_PushTriggerData) MarshalCBOR(w io.Writer) error
func (*Pipeline_PushTriggerData) UnmarshalCBOR ¶
func (t *Pipeline_PushTriggerData) UnmarshalCBOR(r io.Reader) (err error)
type Pipeline_TriggerMetadata ¶
type Pipeline_TriggerMetadata struct {
Kind string `json:"kind" cborgen:"kind"`
Manual *Pipeline_ManualTriggerData `json:"manual,omitempty" cborgen:"manual,omitempty"`
PullRequest *Pipeline_PullRequestTriggerData `json:"pullRequest,omitempty" cborgen:"pullRequest,omitempty"`
Push *Pipeline_PushTriggerData `json:"push,omitempty" cborgen:"push,omitempty"`
Repo *Pipeline_TriggerRepo `json:"repo" cborgen:"repo"`
}
Pipeline_TriggerMetadata is a "triggerMetadata" in the sh.tangled.pipeline schema.
func (*Pipeline_TriggerMetadata) MarshalCBOR ¶
func (t *Pipeline_TriggerMetadata) MarshalCBOR(w io.Writer) error
func (*Pipeline_TriggerMetadata) UnmarshalCBOR ¶
func (t *Pipeline_TriggerMetadata) UnmarshalCBOR(r io.Reader) (err error)
type Pipeline_TriggerRepo ¶
type Pipeline_TriggerRepo struct {
DefaultBranch string `json:"defaultBranch" cborgen:"defaultBranch"`
Did string `json:"did" cborgen:"did"`
Knot string `json:"knot" cborgen:"knot"`
Repo string `json:"repo" cborgen:"repo"`
}
Pipeline_TriggerRepo is a "triggerRepo" in the sh.tangled.pipeline schema.
func (*Pipeline_TriggerRepo) MarshalCBOR ¶
func (t *Pipeline_TriggerRepo) MarshalCBOR(w io.Writer) error
func (*Pipeline_TriggerRepo) UnmarshalCBOR ¶
func (t *Pipeline_TriggerRepo) UnmarshalCBOR(r io.Reader) (err error)
type Pipeline_Workflow ¶
type Pipeline_Workflow struct {
Clone *Pipeline_CloneOpts `json:"clone" cborgen:"clone"`
Engine string `json:"engine" cborgen:"engine"`
Name string `json:"name" cborgen:"name"`
Raw string `json:"raw" cborgen:"raw"`
}
Pipeline_Workflow is a "workflow" in the sh.tangled.pipeline schema.
func (*Pipeline_Workflow) MarshalCBOR ¶
func (t *Pipeline_Workflow) MarshalCBOR(w io.Writer) error
func (*Pipeline_Workflow) UnmarshalCBOR ¶
func (t *Pipeline_Workflow) UnmarshalCBOR(r io.Reader) (err error)
type PublicKey ¶
type PublicKey struct {
LexiconTypeID string `json:"$type,const=sh.tangled.publicKey" cborgen:"$type,const=sh.tangled.publicKey"`
// createdAt: key upload timestamp
CreatedAt string `json:"createdAt" cborgen:"createdAt"`
// key: public key contents
Key string `json:"key" cborgen:"key"`
// name: human-readable name for this key
Name string `json:"name" cborgen:"name"`
}
RECORDTYPE: PublicKey
type Repo ¶
type Repo struct {
LexiconTypeID string `json:"$type,const=sh.tangled.repo" cborgen:"$type,const=sh.tangled.repo"`
CreatedAt string `json:"createdAt" cborgen:"createdAt"`
Description *string `json:"description,omitempty" cborgen:"description,omitempty"`
// knot: knot where the repo was created
Knot string `json:"knot" cborgen:"knot"`
// labels: List of labels that this repo subscribes to
Labels []string `json:"labels,omitempty" cborgen:"labels,omitempty"`
// name: name of the repo
Name string `json:"name" cborgen:"name"`
// source: source of the repo
Source *string `json:"source,omitempty" cborgen:"source,omitempty"`
// spindle: CI runner to send jobs to and receive results from
Spindle *string `json:"spindle,omitempty" cborgen:"spindle,omitempty"`
// topics: Topics related to the repo
Topics []string `json:"topics,omitempty" cborgen:"topics,omitempty"`
// website: Any URI related to the repo
Website *string `json:"website,omitempty" cborgen:"website,omitempty"`
}
RECORDTYPE: Repo
type RepoAddSecret_Input ¶
type RepoAddSecret_Input struct {
Key string `json:"key" cborgen:"key"`
Repo string `json:"repo" cborgen:"repo"`
Value string `json:"value" cborgen:"value"`
}
RepoAddSecret_Input is the input argument to a sh.tangled.repo.addSecret call.
type RepoArtifact ¶
type RepoArtifact struct {
LexiconTypeID string `json:"$type,const=sh.tangled.repo.artifact" cborgen:"$type,const=sh.tangled.repo.artifact"`
// artifact: the artifact
Artifact *util.LexBlob `json:"artifact" cborgen:"artifact"`
// createdAt: time of creation of this artifact
CreatedAt string `json:"createdAt" cborgen:"createdAt"`
// name: name of the artifact
Name string `json:"name" cborgen:"name"`
// repo: repo that this artifact is being uploaded to
Repo string `json:"repo" cborgen:"repo"`
// tag: hash of the tag object that this artifact is attached to (only annotated tags are supported)
Tag util.LexBytes `json:"tag,omitempty" cborgen:"tag,omitempty"`
}
RECORDTYPE: RepoArtifact
func (*RepoArtifact) MarshalCBOR ¶
func (t *RepoArtifact) MarshalCBOR(w io.Writer) error
func (*RepoArtifact) UnmarshalCBOR ¶
func (t *RepoArtifact) UnmarshalCBOR(r io.Reader) (err error)
type RepoBlob_LastCommit ¶
type RepoBlob_LastCommit struct {
Author *RepoBlob_Signature `json:"author,omitempty" cborgen:"author,omitempty"`
// hash: Commit hash
Hash string `json:"hash" cborgen:"hash"`
// message: Commit message
Message string `json:"message" cborgen:"message"`
// when: Commit timestamp
When string `json:"when" cborgen:"when"`
}
RepoBlob_LastCommit is a "lastCommit" in the sh.tangled.repo.blob schema.
type RepoBlob_Output ¶
type RepoBlob_Output struct {
// content: File content (base64 encoded for binary files)
Content *string `json:"content,omitempty" cborgen:"content,omitempty"`
// encoding: Content encoding
Encoding *string `json:"encoding,omitempty" cborgen:"encoding,omitempty"`
// isBinary: Whether the file is binary
IsBinary *bool `json:"isBinary,omitempty" cborgen:"isBinary,omitempty"`
LastCommit *RepoBlob_LastCommit `json:"lastCommit,omitempty" cborgen:"lastCommit,omitempty"`
// mimeType: MIME type of the file
MimeType *string `json:"mimeType,omitempty" cborgen:"mimeType,omitempty"`
// path: The file path
Path string `json:"path" cborgen:"path"`
// ref: The git reference used
Ref string `json:"ref" cborgen:"ref"`
// size: File size in bytes
Size *int64 `json:"size,omitempty" cborgen:"size,omitempty"`
// submodule: Submodule information if path is a submodule
Submodule *RepoBlob_Submodule `json:"submodule,omitempty" cborgen:"submodule,omitempty"`
}
RepoBlob_Output is the output of a sh.tangled.repo.blob call.
func RepoBlob ¶
func RepoBlob(ctx context.Context, c util.LexClient, path string, raw bool, ref string, repo string) (*RepoBlob_Output, error)
RepoBlob calls the XRPC method "sh.tangled.repo.blob".
path: Path to the file within the repository raw: Return raw file content instead of JSON response ref: Git reference (branch, tag, or commit SHA) repo: Repository identifier in format 'did:plc:.../repoName'
type RepoBlob_Signature ¶
type RepoBlob_Signature struct {
// email: Author email
Email string `json:"email" cborgen:"email"`
// name: Author name
Name string `json:"name" cborgen:"name"`
// when: Author timestamp
When string `json:"when" cborgen:"when"`
}
RepoBlob_Signature is a "signature" in the sh.tangled.repo.blob schema.
type RepoBlob_Submodule ¶
type RepoBlob_Submodule struct {
// branch: Branch to track in the submodule
Branch *string `json:"branch,omitempty" cborgen:"branch,omitempty"`
// name: Submodule name
Name string `json:"name" cborgen:"name"`
// url: Submodule repository URL
Url string `json:"url" cborgen:"url"`
}
RepoBlob_Submodule is a "submodule" in the sh.tangled.repo.blob schema.
type RepoBranch_Output ¶
type RepoBranch_Output struct {
Author *RepoBranch_Signature `json:"author,omitempty" cborgen:"author,omitempty"`
// hash: Latest commit hash on this branch
Hash string `json:"hash" cborgen:"hash"`
// isDefault: Whether this is the default branch
IsDefault *bool `json:"isDefault,omitempty" cborgen:"isDefault,omitempty"`
// message: Latest commit message
Message *string `json:"message,omitempty" cborgen:"message,omitempty"`
// name: Branch name
Name string `json:"name" cborgen:"name"`
// shortHash: Short commit hash
ShortHash *string `json:"shortHash,omitempty" cborgen:"shortHash,omitempty"`
// when: Timestamp of latest commit
When string `json:"when" cborgen:"when"`
}
RepoBranch_Output is the output of a sh.tangled.repo.branch call.
type RepoBranch_Signature ¶
type RepoBranch_Signature struct {
// email: Author email
Email string `json:"email" cborgen:"email"`
// name: Author name
Name string `json:"name" cborgen:"name"`
// when: Author timestamp
When string `json:"when" cborgen:"when"`
}
RepoBranch_Signature is a "signature" in the sh.tangled.repo.branch schema.
type RepoCollaborator ¶
type RepoCollaborator struct {
LexiconTypeID string `json:"$type,const=sh.tangled.repo.collaborator" cborgen:"$type,const=sh.tangled.repo.collaborator"`
CreatedAt string `json:"createdAt" cborgen:"createdAt"`
// repo: repo to add this user to
Repo string `json:"repo" cborgen:"repo"`
Subject string `json:"subject" cborgen:"subject"`
}
RECORDTYPE: RepoCollaborator
func (*RepoCollaborator) MarshalCBOR ¶
func (t *RepoCollaborator) MarshalCBOR(w io.Writer) error
func (*RepoCollaborator) UnmarshalCBOR ¶
func (t *RepoCollaborator) UnmarshalCBOR(r io.Reader) (err error)
type RepoCreate_Input ¶
type RepoCreate_Input struct {
// defaultBranch: Default branch to push to
DefaultBranch *string `json:"defaultBranch,omitempty" cborgen:"defaultBranch,omitempty"`
// rkey: Rkey of the repository record
Rkey string `json:"rkey" cborgen:"rkey"`
// source: A source URL to clone from, populate this when forking or importing a repository.
Source *string `json:"source,omitempty" cborgen:"source,omitempty"`
}
RepoCreate_Input is the input argument to a sh.tangled.repo.create call.
type RepoDeleteBranch_Input ¶
type RepoDeleteBranch_Input struct {
Branch string `json:"branch" cborgen:"branch"`
Repo string `json:"repo" cborgen:"repo"`
}
RepoDeleteBranch_Input is the input argument to a sh.tangled.repo.deleteBranch call.
type RepoDelete_Input ¶
type RepoDelete_Input struct {
// did: DID of the repository owner
Did string `json:"did" cborgen:"did"`
// name: Name of the repository to delete
Name string `json:"name" cborgen:"name"`
// rkey: Rkey of the repository record
Rkey string `json:"rkey" cborgen:"rkey"`
}
RepoDelete_Input is the input argument to a sh.tangled.repo.delete call.
type RepoForkStatus_Input ¶
type RepoForkStatus_Input struct {
// branch: Branch to check status for
Branch string `json:"branch" cborgen:"branch"`
// did: DID of the fork owner
Did string `json:"did" cborgen:"did"`
// hiddenRef: Hidden ref to use for comparison
HiddenRef string `json:"hiddenRef" cborgen:"hiddenRef"`
// name: Name of the forked repository
Name string `json:"name" cborgen:"name"`
// source: Source repository URL
Source string `json:"source" cborgen:"source"`
}
RepoForkStatus_Input is the input argument to a sh.tangled.repo.forkStatus call.
type RepoForkStatus_Output ¶
type RepoForkStatus_Output struct {
// status: Fork status: 0=UpToDate, 1=FastForwardable, 2=Conflict, 3=MissingBranch
Status int64 `json:"status" cborgen:"status"`
}
RepoForkStatus_Output is the output of a sh.tangled.repo.forkStatus call.
func RepoForkStatus ¶
func RepoForkStatus(ctx context.Context, c util.LexClient, input *RepoForkStatus_Input) (*RepoForkStatus_Output, error)
RepoForkStatus calls the XRPC method "sh.tangled.repo.forkStatus".
type RepoForkSync_Input ¶
type RepoForkSync_Input struct {
// branch: Branch to sync
Branch string `json:"branch" cborgen:"branch"`
// did: DID of the fork owner
Did string `json:"did" cborgen:"did"`
// name: Name of the forked repository
Name string `json:"name" cborgen:"name"`
// source: AT-URI of the source repository
Source string `json:"source" cborgen:"source"`
}
RepoForkSync_Input is the input argument to a sh.tangled.repo.forkSync call.
type RepoGetDefaultBranch_Output ¶
type RepoGetDefaultBranch_Output struct {
Author *RepoGetDefaultBranch_Signature `json:"author,omitempty" cborgen:"author,omitempty"`
// hash: Latest commit hash on default branch
Hash string `json:"hash" cborgen:"hash"`
// message: Latest commit message
Message *string `json:"message,omitempty" cborgen:"message,omitempty"`
// name: Default branch name
Name string `json:"name" cborgen:"name"`
// shortHash: Short commit hash
ShortHash *string `json:"shortHash,omitempty" cborgen:"shortHash,omitempty"`
// when: Timestamp of latest commit
When string `json:"when" cborgen:"when"`
}
RepoGetDefaultBranch_Output is the output of a sh.tangled.repo.getDefaultBranch call.
type RepoGetDefaultBranch_Signature ¶
type RepoGetDefaultBranch_Signature struct {
// email: Author email
Email string `json:"email" cborgen:"email"`
// name: Author name
Name string `json:"name" cborgen:"name"`
// when: Author timestamp
When string `json:"when" cborgen:"when"`
}
RepoGetDefaultBranch_Signature is a "signature" in the sh.tangled.repo.getDefaultBranch schema.
type RepoHiddenRef_Input ¶
type RepoHiddenRef_Input struct {
// forkRef: Fork reference name
ForkRef string `json:"forkRef" cborgen:"forkRef"`
// remoteRef: Remote reference name
RemoteRef string `json:"remoteRef" cborgen:"remoteRef"`
// repo: AT-URI of the repository
Repo string `json:"repo" cborgen:"repo"`
}
RepoHiddenRef_Input is the input argument to a sh.tangled.repo.hiddenRef call.
type RepoHiddenRef_Output ¶
type RepoHiddenRef_Output struct {
// error: Error message if creation failed
Error *string `json:"error,omitempty" cborgen:"error,omitempty"`
// ref: The created hidden ref name
Ref *string `json:"ref,omitempty" cborgen:"ref,omitempty"`
// success: Whether the hidden ref was created successfully
Success bool `json:"success" cborgen:"success"`
}
RepoHiddenRef_Output is the output of a sh.tangled.repo.hiddenRef call.
func RepoHiddenRef ¶
func RepoHiddenRef(ctx context.Context, c util.LexClient, input *RepoHiddenRef_Input) (*RepoHiddenRef_Output, error)
RepoHiddenRef calls the XRPC method "sh.tangled.repo.hiddenRef".
type RepoIssue ¶
type RepoIssue struct {
LexiconTypeID string `json:"$type,const=sh.tangled.repo.issue" cborgen:"$type,const=sh.tangled.repo.issue"`
Body *string `json:"body,omitempty" cborgen:"body,omitempty"`
CreatedAt string `json:"createdAt" cborgen:"createdAt"`
Mentions []string `json:"mentions,omitempty" cborgen:"mentions,omitempty"`
References []string `json:"references,omitempty" cborgen:"references,omitempty"`
Repo string `json:"repo" cborgen:"repo"`
Title string `json:"title" cborgen:"title"`
}
RECORDTYPE: RepoIssue
type RepoIssueComment ¶
type RepoIssueComment struct {
LexiconTypeID string `json:"$type,const=sh.tangled.repo.issue.comment" cborgen:"$type,const=sh.tangled.repo.issue.comment"`
Body string `json:"body" cborgen:"body"`
CreatedAt string `json:"createdAt" cborgen:"createdAt"`
Issue string `json:"issue" cborgen:"issue"`
Mentions []string `json:"mentions,omitempty" cborgen:"mentions,omitempty"`
References []string `json:"references,omitempty" cborgen:"references,omitempty"`
ReplyTo *string `json:"replyTo,omitempty" cborgen:"replyTo,omitempty"`
}
RECORDTYPE: RepoIssueComment
func (*RepoIssueComment) MarshalCBOR ¶
func (t *RepoIssueComment) MarshalCBOR(w io.Writer) error
func (*RepoIssueComment) UnmarshalCBOR ¶
func (t *RepoIssueComment) UnmarshalCBOR(r io.Reader) (err error)
type RepoIssueState ¶
type RepoIssueState struct {
LexiconTypeID string `json:"$type,const=sh.tangled.repo.issue.state" cborgen:"$type,const=sh.tangled.repo.issue.state"`
Issue string `json:"issue" cborgen:"issue"`
// state: state of the issue
State string `json:"state" cborgen:"state"`
}
RECORDTYPE: RepoIssueState
func (*RepoIssueState) MarshalCBOR ¶
func (t *RepoIssueState) MarshalCBOR(w io.Writer) error
func (*RepoIssueState) UnmarshalCBOR ¶
func (t *RepoIssueState) UnmarshalCBOR(r io.Reader) (err error)
type RepoLanguages_Language ¶
type RepoLanguages_Language struct {
// color: Hex color code for this language
Color *string `json:"color,omitempty" cborgen:"color,omitempty"`
// extensions: File extensions associated with this language
Extensions []string `json:"extensions,omitempty" cborgen:"extensions,omitempty"`
// fileCount: Number of files in this language
FileCount *int64 `json:"fileCount,omitempty" cborgen:"fileCount,omitempty"`
// name: Programming language name
Name string `json:"name" cborgen:"name"`
// percentage: Percentage of total codebase (0-100)
Percentage int64 `json:"percentage" cborgen:"percentage"`
// size: Total size of files in this language (bytes)
Size int64 `json:"size" cborgen:"size"`
}
RepoLanguages_Language is a "language" in the sh.tangled.repo.languages schema.
type RepoLanguages_Output ¶
type RepoLanguages_Output struct {
Languages []*RepoLanguages_Language `json:"languages" cborgen:"languages"`
// ref: The git reference used
Ref string `json:"ref" cborgen:"ref"`
// totalFiles: Total number of files analyzed
TotalFiles *int64 `json:"totalFiles,omitempty" cborgen:"totalFiles,omitempty"`
// totalSize: Total size of all analyzed files in bytes
TotalSize *int64 `json:"totalSize,omitempty" cborgen:"totalSize,omitempty"`
}
RepoLanguages_Output is the output of a sh.tangled.repo.languages call.
func RepoLanguages ¶
func RepoLanguages(ctx context.Context, c util.LexClient, ref string, repo string) (*RepoLanguages_Output, error)
RepoLanguages calls the XRPC method "sh.tangled.repo.languages".
ref: Git reference (branch, tag, or commit SHA) repo: Repository identifier in format 'did:plc:.../repoName'
type RepoListSecrets_Output ¶
type RepoListSecrets_Output struct {
Secrets []*RepoListSecrets_Secret `json:"secrets" cborgen:"secrets"`
}
RepoListSecrets_Output is the output of a sh.tangled.repo.listSecrets call.
type RepoListSecrets_Secret ¶
type RepoListSecrets_Secret struct {
CreatedAt string `json:"createdAt" cborgen:"createdAt"`
CreatedBy string `json:"createdBy" cborgen:"createdBy"`
Key string `json:"key" cborgen:"key"`
Repo string `json:"repo" cborgen:"repo"`
}
RepoListSecrets_Secret is a "secret" in the sh.tangled.repo.listSecrets schema.
type RepoMergeCheck_ConflictInfo ¶
type RepoMergeCheck_ConflictInfo struct {
// filename: Name of the conflicted file
Filename string `json:"filename" cborgen:"filename"`
// reason: Reason for the conflict
Reason string `json:"reason" cborgen:"reason"`
}
RepoMergeCheck_ConflictInfo is a "conflictInfo" in the sh.tangled.repo.mergeCheck schema.
type RepoMergeCheck_Input ¶
type RepoMergeCheck_Input struct {
// branch: Target branch to merge into
Branch string `json:"branch" cborgen:"branch"`
// did: DID of the repository owner
Did string `json:"did" cborgen:"did"`
// name: Name of the repository
Name string `json:"name" cborgen:"name"`
// patch: Patch or pull request to check for merge conflicts
Patch string `json:"patch" cborgen:"patch"`
}
RepoMergeCheck_Input is the input argument to a sh.tangled.repo.mergeCheck call.
type RepoMergeCheck_Output ¶
type RepoMergeCheck_Output struct {
// conflicts: List of files with merge conflicts
Conflicts []*RepoMergeCheck_ConflictInfo `json:"conflicts,omitempty" cborgen:"conflicts,omitempty"`
// error: Error message if check failed
Error *string `json:"error,omitempty" cborgen:"error,omitempty"`
// is_conflicted: Whether the merge has conflicts
Is_conflicted bool `json:"is_conflicted" cborgen:"is_conflicted"`
// message: Additional message about the merge check
Message *string `json:"message,omitempty" cborgen:"message,omitempty"`
}
RepoMergeCheck_Output is the output of a sh.tangled.repo.mergeCheck call.
func RepoMergeCheck ¶
func RepoMergeCheck(ctx context.Context, c util.LexClient, input *RepoMergeCheck_Input) (*RepoMergeCheck_Output, error)
RepoMergeCheck calls the XRPC method "sh.tangled.repo.mergeCheck".
type RepoMerge_Input ¶
type RepoMerge_Input struct {
// authorEmail: Author email for the merge commit
AuthorEmail *string `json:"authorEmail,omitempty" cborgen:"authorEmail,omitempty"`
// authorName: Author name for the merge commit
AuthorName *string `json:"authorName,omitempty" cborgen:"authorName,omitempty"`
// branch: Target branch to merge into
Branch string `json:"branch" cborgen:"branch"`
// commitBody: Additional commit message body
CommitBody *string `json:"commitBody,omitempty" cborgen:"commitBody,omitempty"`
// commitMessage: Merge commit message
CommitMessage *string `json:"commitMessage,omitempty" cborgen:"commitMessage,omitempty"`
// did: DID of the repository owner
Did string `json:"did" cborgen:"did"`
// name: Name of the repository
Name string `json:"name" cborgen:"name"`
// patch: Patch content to merge
Patch string `json:"patch" cborgen:"patch"`
}
RepoMerge_Input is the input argument to a sh.tangled.repo.merge call.
type RepoPull ¶
type RepoPull struct {
LexiconTypeID string `json:"$type,const=sh.tangled.repo.pull" cborgen:"$type,const=sh.tangled.repo.pull"`
Body *string `json:"body,omitempty" cborgen:"body,omitempty"`
CreatedAt string `json:"createdAt" cborgen:"createdAt"`
Mentions []string `json:"mentions,omitempty" cborgen:"mentions,omitempty"`
// patch: (deprecated) use patchBlob instead
Patch *string `json:"patch,omitempty" cborgen:"patch,omitempty"`
// patchBlob: patch content
PatchBlob *util.LexBlob `json:"patchBlob" cborgen:"patchBlob"`
References []string `json:"references,omitempty" cborgen:"references,omitempty"`
Source *RepoPull_Source `json:"source,omitempty" cborgen:"source,omitempty"`
Target *RepoPull_Target `json:"target" cborgen:"target"`
Title string `json:"title" cborgen:"title"`
}
RECORDTYPE: RepoPull
type RepoPullComment ¶
type RepoPullComment struct {
LexiconTypeID string `json:"$type,const=sh.tangled.repo.pull.comment" cborgen:"$type,const=sh.tangled.repo.pull.comment"`
Body string `json:"body" cborgen:"body"`
CreatedAt string `json:"createdAt" cborgen:"createdAt"`
Mentions []string `json:"mentions,omitempty" cborgen:"mentions,omitempty"`
Pull string `json:"pull" cborgen:"pull"`
References []string `json:"references,omitempty" cborgen:"references,omitempty"`
}
RECORDTYPE: RepoPullComment
func (*RepoPullComment) MarshalCBOR ¶
func (t *RepoPullComment) MarshalCBOR(w io.Writer) error
func (*RepoPullComment) UnmarshalCBOR ¶
func (t *RepoPullComment) UnmarshalCBOR(r io.Reader) (err error)
type RepoPullStatus ¶
type RepoPullStatus struct {
LexiconTypeID string `json:"$type,const=sh.tangled.repo.pull.status" cborgen:"$type,const=sh.tangled.repo.pull.status"`
Pull string `json:"pull" cborgen:"pull"`
// status: status of the pull request
Status string `json:"status" cborgen:"status"`
}
RECORDTYPE: RepoPullStatus
func (*RepoPullStatus) MarshalCBOR ¶
func (t *RepoPullStatus) MarshalCBOR(w io.Writer) error
func (*RepoPullStatus) UnmarshalCBOR ¶
func (t *RepoPullStatus) UnmarshalCBOR(r io.Reader) (err error)
type RepoPull_Source ¶
type RepoPull_Source struct {
Branch string `json:"branch" cborgen:"branch"`
Repo *string `json:"repo,omitempty" cborgen:"repo,omitempty"`
Sha string `json:"sha" cborgen:"sha"`
}
RepoPull_Source is a "source" in the sh.tangled.repo.pull schema.
func (*RepoPull_Source) MarshalCBOR ¶
func (t *RepoPull_Source) MarshalCBOR(w io.Writer) error
func (*RepoPull_Source) UnmarshalCBOR ¶
func (t *RepoPull_Source) UnmarshalCBOR(r io.Reader) (err error)
type RepoPull_Target ¶
type RepoPull_Target struct {
Branch string `json:"branch" cborgen:"branch"`
Repo string `json:"repo" cborgen:"repo"`
}
RepoPull_Target is a "target" in the sh.tangled.repo.pull schema.
func (*RepoPull_Target) MarshalCBOR ¶
func (t *RepoPull_Target) MarshalCBOR(w io.Writer) error
func (*RepoPull_Target) UnmarshalCBOR ¶
func (t *RepoPull_Target) UnmarshalCBOR(r io.Reader) (err error)
type RepoRemoveSecret_Input ¶
type RepoRemoveSecret_Input struct {
Key string `json:"key" cborgen:"key"`
Repo string `json:"repo" cborgen:"repo"`
}
RepoRemoveSecret_Input is the input argument to a sh.tangled.repo.removeSecret call.
type RepoSetDefaultBranch_Input ¶
type RepoSetDefaultBranch_Input struct {
DefaultBranch string `json:"defaultBranch" cborgen:"defaultBranch"`
Repo string `json:"repo" cborgen:"repo"`
}
RepoSetDefaultBranch_Input is the input argument to a sh.tangled.repo.setDefaultBranch call.
type RepoTree_LastCommit ¶
type RepoTree_LastCommit struct {
Author *RepoTree_Signature `json:"author,omitempty" cborgen:"author,omitempty"`
// hash: Commit hash
Hash string `json:"hash" cborgen:"hash"`
// message: Commit message
Message string `json:"message" cborgen:"message"`
// when: Commit timestamp
When string `json:"when" cborgen:"when"`
}
RepoTree_LastCommit is a "lastCommit" in the sh.tangled.repo.tree schema.
type RepoTree_Output ¶
type RepoTree_Output struct {
// dotdot: Parent directory path
Dotdot *string `json:"dotdot,omitempty" cborgen:"dotdot,omitempty"`
Files []*RepoTree_TreeEntry `json:"files" cborgen:"files"`
LastCommit *RepoTree_LastCommit `json:"lastCommit,omitempty" cborgen:"lastCommit,omitempty"`
// parent: The parent path in the tree
Parent *string `json:"parent,omitempty" cborgen:"parent,omitempty"`
// readme: Readme for this file tree
Readme *RepoTree_Readme `json:"readme,omitempty" cborgen:"readme,omitempty"`
// ref: The git reference used
Ref string `json:"ref" cborgen:"ref"`
}
RepoTree_Output is the output of a sh.tangled.repo.tree call.
func RepoTree ¶
func RepoTree(ctx context.Context, c util.LexClient, path string, ref string, repo string) (*RepoTree_Output, error)
RepoTree calls the XRPC method "sh.tangled.repo.tree".
path: Path within the repository tree ref: Git reference (branch, tag, or commit SHA) repo: Repository identifier in format 'did:plc:.../repoName'
type RepoTree_Readme ¶
type RepoTree_Readme struct {
// contents: Contents of the readme file
Contents string `json:"contents" cborgen:"contents"`
// filename: Name of the readme file
Filename string `json:"filename" cborgen:"filename"`
}
RepoTree_Readme is a "readme" in the sh.tangled.repo.tree schema.
type RepoTree_Signature ¶
type RepoTree_Signature struct {
// email: Author email
Email string `json:"email" cborgen:"email"`
// name: Author name
Name string `json:"name" cborgen:"name"`
// when: Author timestamp
When string `json:"when" cborgen:"when"`
}
RepoTree_Signature is a "signature" in the sh.tangled.repo.tree schema.
type RepoTree_TreeEntry ¶
type RepoTree_TreeEntry struct {
Last_commit *RepoTree_LastCommit `json:"last_commit,omitempty" cborgen:"last_commit,omitempty"`
// mode: File mode
Mode string `json:"mode" cborgen:"mode"`
// name: Relative file or directory name
Name string `json:"name" cborgen:"name"`
// size: File size in bytes
Size int64 `json:"size" cborgen:"size"`
}
RepoTree_TreeEntry is a "treeEntry" in the sh.tangled.repo.tree schema.
type Spindle ¶
type Spindle struct {
LexiconTypeID string `json:"$type,const=sh.tangled.spindle" cborgen:"$type,const=sh.tangled.spindle"`
CreatedAt string `json:"createdAt" cborgen:"createdAt"`
}
RECORDTYPE: Spindle
type SpindleMember ¶
type SpindleMember struct {
LexiconTypeID string `json:"$type,const=sh.tangled.spindle.member" cborgen:"$type,const=sh.tangled.spindle.member"`
CreatedAt string `json:"createdAt" cborgen:"createdAt"`
// instance: spindle instance that the subject is now a member of
Instance string `json:"instance" cborgen:"instance"`
Subject string `json:"subject" cborgen:"subject"`
}
RECORDTYPE: SpindleMember
func (*SpindleMember) MarshalCBOR ¶
func (t *SpindleMember) MarshalCBOR(w io.Writer) error
func (*SpindleMember) UnmarshalCBOR ¶
func (t *SpindleMember) UnmarshalCBOR(r io.Reader) (err error)
type String ¶
type String struct {
LexiconTypeID string `json:"$type,const=sh.tangled.string" cborgen:"$type,const=sh.tangled.string"`
Contents string `json:"contents" cborgen:"contents"`
CreatedAt string `json:"createdAt" cborgen:"createdAt"`
Description string `json:"description" cborgen:"description"`
Filename string `json:"filename" cborgen:"filename"`
}
RECORDTYPE: String
Source Files
¶
- actorprofile.go
- cbor_gen.go
- feedreaction.go
- feedstar.go
- gitrefUpdate.go
- graphfollow.go
- issuecomment.go
- issuestate.go
- knotlistKeys.go
- knotmember.go
- knotversion.go
- labeldefinition.go
- labelop.go
- pipelinecancelPipeline.go
- pipelinestatus.go
- pullcomment.go
- pullstatus.go
- repoaddSecret.go
- repoarchive.go
- repoartifact.go
- repoblob.go
- repobranch.go
- repobranches.go
- repocollaborator.go
- repocompare.go
- repocreate.go
- repodelete.go
- repodeleteBranch.go
- repodiff.go
- repoforkStatus.go
- repoforkSync.go
- repogetDefaultBranch.go
- repohiddenRef.go
- repoissue.go
- repolanguages.go
- repolistSecrets.go
- repolog.go
- repomerge.go
- repomergeCheck.go
- repopull.go
- reporemoveSecret.go
- reposetDefaultBranch.go
- repotag.go
- repotags.go
- repotree.go
- spindlemember.go
- stateclosed.go
- stateopen.go
- statusclosed.go
- statusmerged.go
- statusopen.go
- tangledknot.go
- tangledowner.go
- tangledpipeline.go
- tangledpublicKey.go
- tangledrepo.go
- tangledspindle.go
- tangledstring.go